==> ginkgo-hpc-docs-1.7.0-5-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/variables_b.js <==
var searchData=
[
  ['major_0',['major',['../structgko_1_1version.html#a019ce1d31714612e0c77c8ef5eb4cfde',1,'gko::version']]],
  ['max_5fblock_5fsize_1',['max_block_size',['../structgko_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#a7d11d10b347b25b64b5b916e6a74364e',1,'gko::preconditioner::Jacobi::parameters_type']]],
  ['max_5fblock_5fstride_2',['max_block_stride',['../structgko_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#a042df68c54ea721101c4b064ed450a1f',1,'gko::preconditioner::Jacobi::parameters_type']]],
  ['max_5fiterations_3',['max_iterations',['../structgko_1_1multigrid_1_1Pgm_1_1parameters__type.html#afc511fbee9d2ea44e611275d8b287a82',1,'gko::multigrid::Pgm::parameters_type::max_iterations'],['../structgko_1_1batch_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters.html#a27570adff31e3558786aced9c2a0042c',1,'gko::batch::solver::enable_preconditioned_iterative_solver_factory_parameters::max_iterations']]],
  ['max_5fiters_4',['max_iters',['../structgko_1_1stop_1_1Iteration_1_1parameters__type.html#a7daf7ecb5cf107b9e7444b0898f691c4',1,'gko::stop::Iteration::parameters_type']]],
  ['max_5flevels_5',['max_levels',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#a2e4dd4ccd56c5becbbc60d3538b8dfe6',1,'gko::solver::Multigrid::parameters_type']]],
  ['max_5funassigned_5fratio_6',['max_unassigned_ratio',['../structgko_1_1multigrid_1_1Pgm_1_1parameters__type.html#a84f566c53173ae409ff6916f052ddcf4',1,'gko::multigrid::Pgm::parameters_type']]],
  ['mg_5flevel_7',['mg_level',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#af8671d3890209b0063dae79c31ce489d',1,'gko::solver::Multigrid::parameters_type']]],
  ['mid_5fcase_8',['mid_case',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#abc24bca2fd9c007318d9d135f9b04ab6',1,'gko::solver::Multigrid::parameters_type']]],
  ['mid_5fsmoother_9',['mid_smoother',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#ac9cfc41847d5f9fe9b01b260a07e1d39',1,'gko::solver::Multigrid::parameters_type']]],
  ['min_5fcoarse_5frows_10',['min_coarse_rows',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#a6ad3e4e874e1fcc987b269e3473449c6',1,'gko::solver::Multigrid::parameters_type']]],
  ['minor_11',['minor',['../structgko_1_1version.html#abb548e6dca39e0a3718ecf13cafbba36',1,'gko::version']]]
];

==> ginkgo-hpc-docs-1.11.0-3-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/variables_b.js <==
var searchData=
[
  ['major_0',['major',['../structgko_1_1version.html#a019ce1d31714612e0c77c8ef5eb4cfde',1,'gko::version']]],
  ['max_5fblock_5fsize_1',['max_block_size',['../structgko_1_1batch_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#a06ada09498ccd4f438aa5107d66d83e9',1,'gko::batch::preconditioner::Jacobi::parameters_type::max_block_size'],['../structgko_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#a7d11d10b347b25b64b5b916e6a74364e',1,'gko::preconditioner::Jacobi::parameters_type::max_block_size']]],
  ['max_5fblock_5fstride_2',['max_block_stride',['../structgko_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#a042df68c54ea721101c4b064ed450a1f',1,'gko::preconditioner::Jacobi::parameters_type']]],
  ['max_5fiterations_3',['max_iterations',['../structgko_1_1multigrid_1_1Pgm_1_1parameters__type.html#afc511fbee9d2ea44e611275d8b287a82',1,'gko::multigrid::Pgm::parameters_type::max_iterations'],['../structgko_1_1batch_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters.html#a27570adff31e3558786aced9c2a0042c',1,'gko::batch::solver::enable_preconditioned_iterative_solver_factory_parameters::max_iterations']]],
  ['max_5fiters_4',['max_iters',['../structgko_1_1stop_1_1Iteration_1_1parameters__type.html#a7daf7ecb5cf107b9e7444b0898f691c4',1,'gko::stop::Iteration::parameters_type']]],
  ['max_5flevels_5',['max_levels',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#a2e4dd4ccd56c5becbbc60d3538b8dfe6',1,'gko::solver::Multigrid::parameters_type']]],
  ['max_5funassigned_5fratio_6',['max_unassigned_ratio',['../structgko_1_1multigrid_1_1Pgm_1_1parameters__type.html#a84f566c53173ae409ff6916f052ddcf4',1,'gko::multigrid::Pgm::parameters_type']]],
  ['mg_5flevel_7',['mg_level',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#af8671d3890209b0063dae79c31ce489d',1,'gko::solver::Multigrid::parameters_type']]],
  ['mid_5fcase_8',['mid_case',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#abc24bca2fd9c007318d9d135f9b04ab6',1,'gko::solver::Multigrid::parameters_type']]],
  ['mid_5fsmoother_9',['mid_smoother',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#ac9cfc41847d5f9fe9b01b260a07e1d39',1,'gko::solver::Multigrid::parameters_type']]],
  ['min_5fcoarse_5frows_10',['min_coarse_rows',['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#a6ad3e4e874e1fcc987b269e3473449c6',1,'gko::solver::Multigrid::parameters_type']]],
  ['minor_11',['minor',['../structgko_1_1version.html#abb548e6dca39e0a3718ecf13cafbba36',1,'gko::version']]]
];
